SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0;
SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0;
SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='TRADITIONAL';

DROP SCHEMA IF EXISTS `datoswebeval` ;
CREATE SCHEMA IF NOT EXISTS `datoswebeval` DEFAULT CHARACTER SET utf8 COLLATE utf8_spanish_ci ;

-- -----------------------------------------------------
-- Table `datoswebeval`.`centro`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `datoswebeval`.`centro` ;

CREATE  TABLE IF NOT EXISTS `datoswebeval`.`centro` (
  `id` INT NOT NULL AUTO_INCREMENT ,
  `nombre` VARCHAR(128) CHARACTER SET 'utf8' COLLATE 'utf8_spanish_ci' NOT NULL ,
  `siglas` VARCHAR(48) CHARACTER SET 'utf8' COLLATE 'utf8_spanish_ci' NOT NULL ,
  `descripcion` TEXT CHARACTER SET 'utf8' COLLATE 'utf8_spanish_ci' NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) )
ENGINE = InnoDB
AUTO_INCREMENT = 1
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_spanish_ci;


-- -----------------------------------------------------
-- Table `datoswebeval`.`curso`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `datoswebeval`.`curso` ;

CREATE  TABLE IF NOT EXISTS `datoswebeval`.`curso` (
  `id` INT NOT NULL AUTO_INCREMENT ,
  `nombre` VARCHAR(256) NOT NULL ,
  `descripcion` VARCHAR(1024) NULL ,
  PRIMARY KEY (`id`) )
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_spanish_ci;


-- -----------------------------------------------------
-- Table `datoswebeval`.`asignatura`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `datoswebeval`.`asignatura` ;

CREATE  TABLE IF NOT EXISTS `datoswebeval`.`asignatura` (
  `id` INT NOT NULL AUTO_INCREMENT ,
  `codigo` VARCHAR(16) CHARACTER SET 'utf8' COLLATE 'utf8_spanish_ci' NULL DEFAULT NULL ,
  `siglas` VARCHAR(48) CHARACTER SET 'utf8' COLLATE 'utf8_spanish_ci' NULL DEFAULT NULL ,
  `nombre` VARCHAR(128) CHARACTER SET 'utf8' COLLATE 'utf8_spanish_ci' NULL DEFAULT NULL ,
  `descripcion` TEXT CHARACTER SET 'utf8' COLLATE 'utf8_spanish_ci' NULL DEFAULT NULL ,
  `creditos_teoria` FLOAT NULL DEFAULT NULL ,
  `creditos_laboratorio` FLOAT NULL DEFAULT NULL ,
  `centro_id` INT NOT NULL ,
  `curso_id` INT NOT NULL ,
  PRIMARY KEY (`id`, `centro_id`, `curso_id`) ,
  INDEX `fk_asignatura_centro1` (`centro_id` ASC) ,
  INDEX `fk_asignatura_curso1` (`curso_id` ASC) ,
  CONSTRAINT `fk_asignatura_centro1`
    FOREIGN KEY (`centro_id` )
    REFERENCES `datoswebeval`.`centro` (`id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_asignatura_curso1`
    FOREIGN KEY (`curso_id` )
    REFERENCES `datoswebeval`.`curso` (`id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB
AUTO_INCREMENT = 0
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_spanish_ci;


-- -----------------------------------------------------
-- Table `datoswebeval`.`autor`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `datoswebeval`.`autor` ;

CREATE  TABLE IF NOT EXISTS `datoswebeval`.`autor` (
  `id` INT NOT NULL AUTO_INCREMENT ,
  `dni` VARCHAR(16) CHARACTER SET 'utf8' COLLATE 'utf8_spanish_ci' NULL DEFAULT NULL ,
  `primerNombre` VARCHAR(64) CHARACTER SET 'utf8' COLLATE 'utf8_spanish_ci' NULL DEFAULT NULL ,
  `segundoNombre` VARCHAR(64) CHARACTER SET 'utf8' COLLATE 'utf8_spanish_ci' NULL DEFAULT NULL ,
  `apellidoPaterno` VARCHAR(64) CHARACTER SET 'utf8' COLLATE 'utf8_spanish_ci' NULL DEFAULT NULL ,
  `apellidoMaterno` VARCHAR(64) CHARACTER SET 'utf8' COLLATE 'utf8_spanish_ci' NULL DEFAULT NULL ,
  `direccion` TINYTEXT CHARACTER SET 'utf8' COLLATE 'utf8_spanish_ci' NULL DEFAULT NULL ,
  `telefono` VARCHAR(64) CHARACTER SET 'utf8' COLLATE 'utf8_spanish_ci' NULL DEFAULT NULL ,
  `movilA` VARCHAR(64) CHARACTER SET 'utf8' COLLATE 'utf8_spanish_ci' NULL DEFAULT NULL ,
  `usuario` VARCHAR(128) CHARACTER SET 'utf8' COLLATE 'utf8_spanish_ci' NULL DEFAULT NULL ,
  `clave` VARCHAR(256) CHARACTER SET 'utf8' COLLATE 'utf8_spanish_ci' NULL DEFAULT NULL ,
  `email` VARCHAR(128) CHARACTER SET 'utf8' COLLATE 'utf8_spanish_ci' NULL DEFAULT NULL ,
  `despacho` VARCHAR(128) CHARACTER SET 'utf8' COLLATE 'utf8_spanish_ci' NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) )
ENGINE = InnoDB
AUTO_INCREMENT = 1
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_spanish_ci;


-- -----------------------------------------------------
-- Table `datoswebeval`.`tipo`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `datoswebeval`.`tipo` ;

CREATE  TABLE IF NOT EXISTS `datoswebeval`.`tipo` (
  `id` INT NOT NULL AUTO_INCREMENT ,
  `nombre` VARCHAR(128) CHARACTER SET 'utf8' COLLATE 'utf8_spanish_ci' NOT NULL ,
  `descripcion` TINYTEXT CHARACTER SET 'utf8' COLLATE 'utf8_spanish_ci' NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) )
ENGINE = InnoDB
AUTO_INCREMENT = 4
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_spanish_ci;


-- -----------------------------------------------------
-- Table `datoswebeval`.`pregunta`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `datoswebeval`.`pregunta` ;

CREATE  TABLE IF NOT EXISTS `datoswebeval`.`pregunta` (
  `id` INT NOT NULL AUTO_INCREMENT ,
  `fecha_creacion` DATE NULL DEFAULT NULL ,
  `fecha_modificacion` DATE NULL DEFAULT NULL ,
  `titulo` VARCHAR(128) CHARACTER SET 'utf8' COLLATE 'utf8_spanish_ci' NULL DEFAULT NULL ,
  `codigo` VARCHAR(512) NULL DEFAULT 'YYYY-MM-DD' ,
  `enunciado` TEXT CHARACTER SET 'utf8' COLLATE 'utf8_spanish_ci' NULL DEFAULT NULL ,
  `palabras_clave` TEXT CHARACTER SET 'utf8' COLLATE 'utf8_spanish_ci' NULL DEFAULT NULL ,
  `dificultad` FLOAT NULL DEFAULT NULL ,
  `tipo_id` INT NOT NULL ,
  PRIMARY KEY (`id`) ,
  INDEX `fk_pregunta_tipo1` (`tipo_id` ASC) ,
  CONSTRAINT `fk_pregunta_tipo1`
    FOREIGN KEY (`tipo_id` )
    REFERENCES `datoswebeval`.`tipo` (`id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB
AUTO_INCREMENT = 3
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_spanish_ci;


-- -----------------------------------------------------
-- Table `datoswebeval`.`autor_has_pregunta`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `datoswebeval`.`autor_has_pregunta` ;

CREATE  TABLE IF NOT EXISTS `datoswebeval`.`autor_has_pregunta` (
  `autor_id` INT NOT NULL ,
  `pregunta_id` INT NOT NULL ,
  PRIMARY KEY (`autor_id`, `pregunta_id`) ,
  INDEX `fk_autor_has_pregunta_pregunta1` (`pregunta_id` ASC) ,
  INDEX `fk_autor_has_pregunta_autor` (`autor_id` ASC) ,
  CONSTRAINT `fk_autor_has_pregunta_autor`
    FOREIGN KEY (`autor_id` )
    REFERENCES `datoswebeval`.`autor` (`id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_autor_has_pregunta_pregunta1`
    FOREIGN KEY (`pregunta_id` )
    REFERENCES `datoswebeval`.`pregunta` (`id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_spanish_ci;


-- -----------------------------------------------------
-- Table `datoswebeval`.`tema`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `datoswebeval`.`tema` ;

CREATE  TABLE IF NOT EXISTS `datoswebeval`.`tema` (
  `id` INT NOT NULL AUTO_INCREMENT ,
  `nombre` VARCHAR(128) CHARACTER SET 'utf8' COLLATE 'utf8_spanish_ci' NOT NULL ,
  `numero_tema` INT NOT NULL ,
  `descripcion` TINYTEXT CHARACTER SET 'utf8' COLLATE 'utf8_spanish_ci' NULL DEFAULT NULL ,
  `asignatura_id` INT NOT NULL ,
  `asignatura_centro_idcentro` INT NOT NULL ,
  PRIMARY KEY (`id`, `asignatura_id`, `asignatura_centro_idcentro`) ,
  INDEX `fk_tema_asignatura1` (`asignatura_id` ASC, `asignatura_centro_idcentro` ASC) ,
  CONSTRAINT `fk_tema_asignatura1`
    FOREIGN KEY (`asignatura_id` , `asignatura_centro_idcentro` )
    REFERENCES `datoswebeval`.`asignatura` (`id` , `centro_id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB
AUTO_INCREMENT = 9
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_spanish_ci;


-- -----------------------------------------------------
-- Table `datoswebeval`.`alumno`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `datoswebeval`.`alumno` ;

CREATE  TABLE IF NOT EXISTS `datoswebeval`.`alumno` (
  `id` INT NOT NULL AUTO_INCREMENT ,
  `dni` VARCHAR(16) CHARACTER SET 'utf8' COLLATE 'utf8_spanish_ci' NULL DEFAULT NULL ,
  `primerNombre` VARCHAR(64) CHARACTER SET 'utf8' COLLATE 'utf8_spanish_ci' NULL DEFAULT NULL ,
  `segundoNombre` VARCHAR(64) CHARACTER SET 'utf8' COLLATE 'utf8_spanish_ci' NULL DEFAULT NULL ,
  `apellidoPaterno` VARCHAR(64) CHARACTER SET 'utf8' COLLATE 'utf8_spanish_ci' NULL DEFAULT NULL ,
  `apellidoMaterno` VARCHAR(64) CHARACTER SET 'utf8' COLLATE 'utf8_spanish_ci' NULL DEFAULT NULL ,
  `direccion` TINYTEXT CHARACTER SET 'utf8' COLLATE 'utf8_spanish_ci' NULL DEFAULT NULL ,
  `telefono` VARCHAR(64) CHARACTER SET 'utf8' COLLATE 'utf8_spanish_ci' NULL DEFAULT NULL ,
  `movilA` VARCHAR(64) CHARACTER SET 'utf8' COLLATE 'utf8_spanish_ci' NULL DEFAULT NULL ,
  `usuario` VARCHAR(128) CHARACTER SET 'utf8' COLLATE 'utf8_spanish_ci' NULL DEFAULT NULL ,
  `clave` VARCHAR(256) CHARACTER SET 'utf8' COLLATE 'utf8_spanish_ci' NULL DEFAULT NULL ,
  `email` VARCHAR(128) CHARACTER SET 'utf8' COLLATE 'utf8_spanish_ci' NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) )
ENGINE = InnoDB
AUTO_INCREMENT = 3
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_spanish_ci;


-- -----------------------------------------------------
-- Table `datoswebeval`.`evaluacion`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `datoswebeval`.`evaluacion` ;

CREATE  TABLE IF NOT EXISTS `datoswebeval`.`evaluacion` (
  `id` INT NOT NULL AUTO_INCREMENT ,
  `asignatura_id` INT NOT NULL ,
  `autor_id` INT NOT NULL ,
  `tema_id` INT NULL ,
  `titulo` VARCHAR(45) NULL ,
  `fecha_apertura` DATETIME NULL ,
  `fecha_cierre` DATETIME NULL ,
  `valor` FLOAT NULL ,
  `grado_confianza` TINYINT(1)  NULL ,
  `publicado` TINYINT(1)  NULL ,
  `pdf_plantilla` TINYTEXT CHARACTER SET 'utf8' COLLATE 'utf8_spanish_ci' NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) )
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_spanish_ci;


-- -----------------------------------------------------
-- Table `datoswebeval`.`matricula`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `datoswebeval`.`matricula` ;

CREATE  TABLE IF NOT EXISTS `datoswebeval`.`matricula` (
  `alumno_id` INT NOT NULL ,
  `asignatura_id` INT NOT NULL ,
  `asignatura_centro_id` INT NOT NULL ,
  `asignatura_curso_id` INT NOT NULL ,
  PRIMARY KEY (`alumno_id`, `asignatura_id`, `asignatura_centro_id`, `asignatura_curso_id`) ,
  INDEX `fk_matricula_asignatura1` (`asignatura_id` ASC, `asignatura_centro_id` ASC, `asignatura_curso_id` ASC) ,
  CONSTRAINT `fk_matricula_alumno1`
    FOREIGN KEY (`alumno_id` )
    REFERENCES `datoswebeval`.`alumno` (`id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_matricula_asignatura1`
    FOREIGN KEY (`asignatura_id` , `asignatura_centro_id` )
    REFERENCES `datoswebeval`.`asignatura` (`id` , `centro_id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_spanish_ci;


-- -----------------------------------------------------
-- Table `datoswebeval`.`evaluacion_alumno`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `datoswebeval`.`evaluacion_alumno` ;

CREATE  TABLE IF NOT EXISTS `datoswebeval`.`evaluacion_alumno` (
  `id` INT NOT NULL AUTO_INCREMENT ,
  `evaluacion_id` INT NOT NULL ,
  `fecha` DATETIME NOT NULL ,
  `nota` FLOAT NOT NULL ,
  `comentarios` TINYTEXT NULL ,
  `matricula_alumno_id` INT NOT NULL ,
  `matricula_asignatura_id` INT NOT NULL ,
  `matricula_asignatura_centro_idcentro` INT NOT NULL ,
  `matricula_asignatura_curso_id` INT NOT NULL ,
  `finalizado` TINYINT(1)  NULL ,
  `corregido` TINYINT(1)  NULL ,
  `pdf_respuestas` TINYTEXT CHARACTER SET 'utf8' COLLATE 'utf8_spanish_ci' NULL DEFAULT NULL ,
  `pdf_correccion` TINYTEXT CHARACTER SET 'utf8' COLLATE 'utf8_spanish_ci' NULL DEFAULT NULL ,
  PRIMARY KEY (`id`, `evaluacion_id`, `matricula_alumno_id`, `matricula_asignatura_id`, `matricula_asignatura_centro_idcentro`, `matricula_asignatura_curso_id`) ,
  INDEX `fk_evaluacion_alumno_evaluacion1` (`evaluacion_id` ASC) ,
  INDEX `fk_evaluacion_alumno_matricula1` (`matricula_alumno_id` ASC, `matricula_asignatura_id` ASC, `matricula_asignatura_centro_idcentro` ASC, `matricula_asignatura_curso_id` ASC) ,
  CONSTRAINT `fk_evaluacion_alumno_evaluacion1`
    FOREIGN KEY (`evaluacion_id` )
    REFERENCES `datoswebeval`.`evaluacion` (`id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_evaluacion_alumno_matricula1`
    FOREIGN KEY (`matricula_alumno_id` , `matricula_asignatura_id` , `matricula_asignatura_centro_idcentro` , `matricula_asignatura_curso_id` )
    REFERENCES `datoswebeval`.`matricula` (`alumno_id` , `asignatura_id` , `asignatura_centro_id` , `asignatura_curso_id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_spanish_ci;


-- -----------------------------------------------------
-- Table `datoswebeval`.`pregunta_o_m`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `datoswebeval`.`pregunta_o_m` ;

CREATE  TABLE IF NOT EXISTS `datoswebeval`.`pregunta_o_m` (
  `id` INT NOT NULL AUTO_INCREMENT ,
  `pregunta_id` INT NOT NULL ,
  `respuesta` TEXT NOT NULL ,
  `correcta` TINYINT(1)  NOT NULL ,
  `refuerzo` TINYTEXT NULL ,
  PRIMARY KEY (`id`, `pregunta_id`) ,
  CONSTRAINT `fk_pregunta_o_m_pregunta1`
    FOREIGN KEY (`pregunta_id` )
    REFERENCES `datoswebeval`.`pregunta` (`id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_spanish_ci;


-- -----------------------------------------------------
-- Table `datoswebeval`.`pregunta_r_l`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `datoswebeval`.`pregunta_r_l` ;

CREATE  TABLE IF NOT EXISTS `datoswebeval`.`pregunta_r_l` (
  `pregunta_id` INT NOT NULL ,
  `respuesta_posible` TEXT NOT NULL ,
  PRIMARY KEY (`pregunta_id`) ,
  CONSTRAINT `fk_pregunta_r_l_pregunta1`
    FOREIGN KEY (`pregunta_id` )
    REFERENCES `datoswebeval`.`pregunta` (`id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_spanish_ci;


-- -----------------------------------------------------
-- Table `datoswebeval`.`pregunta_tema`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `datoswebeval`.`pregunta_tema` ;

CREATE  TABLE IF NOT EXISTS `datoswebeval`.`pregunta_tema` (
  `pregunta_id` INT NOT NULL ,
  `tema_id` INT NOT NULL ,
  `tema_asignatura_id` INT NOT NULL ,
  `tema_asignatura_centro_idcentro` INT NOT NULL ,
  PRIMARY KEY (`pregunta_id`, `tema_id`, `tema_asignatura_id`, `tema_asignatura_centro_idcentro`) ,
  INDEX `fk_pregunta_tema_pregunta1` (`pregunta_id` ASC) ,
  INDEX `fk_pregunta_tema_tema1` (`tema_id` ASC, `tema_asignatura_id` ASC, `tema_asignatura_centro_idcentro` ASC) ,
  CONSTRAINT `fk_pregunta_tema_pregunta1`
    FOREIGN KEY (`pregunta_id` )
    REFERENCES `datoswebeval`.`pregunta` (`id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_pregunta_tema_tema1`
    FOREIGN KEY (`tema_id` , `tema_asignatura_id` , `tema_asignatura_centro_idcentro` )
    REFERENCES `datoswebeval`.`tema` (`id` , `asignatura_id` , `asignatura_centro_idcentro` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_spanish_ci;


-- -----------------------------------------------------
-- Table `datoswebeval`.`pregunta_v_f`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `datoswebeval`.`pregunta_v_f` ;

CREATE  TABLE IF NOT EXISTS `datoswebeval`.`pregunta_v_f` (
  `pregunta_id` INT NOT NULL ,
  `correcta` TINYINT(1)  NOT NULL ,
  `refuerzo_positivo` TINYTEXT NULL ,
  `refuerzo_negativo` TINYTEXT NULL ,
  PRIMARY KEY (`pregunta_id`) ,
  CONSTRAINT `fk_pregunta_v_f_pregunta1`
    FOREIGN KEY (`pregunta_id` )
    REFERENCES `datoswebeval`.`pregunta` (`id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_spanish_ci;


-- -----------------------------------------------------
-- Table `datoswebeval`.`respuesta_alumno`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `datoswebeval`.`respuesta_alumno` ;

CREATE  TABLE IF NOT EXISTS `datoswebeval`.`respuesta_alumno` (
  `id` INT NOT NULL AUTO_INCREMENT ,
  `pregunta_id` INT NOT NULL ,
  `evaluacion_alumno_id` INT NOT NULL ,
  `alumno_id` INT NOT NULL ,
  `evaluacion_pregunta_id` INT NOT NULL ,
  `vf` TINYINT(1)  NULL ,
  `om` INT NULL ,
  `rl` TEXT NULL ,
  `svg` TEXT NULL ,
  `nota` FLOAT NULL ,
  `grado_confianza` INT NULL ,
  PRIMARY KEY (`id`, `pregunta_id`, `evaluacion_alumno_id`, `alumno_id`) )
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_spanish_ci;


-- -----------------------------------------------------
-- Table `datoswebeval`.`menu_gestion`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `datoswebeval`.`menu_gestion` ;

CREATE  TABLE IF NOT EXISTS `datoswebeval`.`menu_gestion` (
  `id` INT NOT NULL AUTO_INCREMENT ,
  `nombre` VARCHAR(45) NULL ,
  `orden` INT NULL ,
  `vista` VARCHAR(45) NULL ,
  `imagen` VARCHAR(45) NULL ,
  PRIMARY KEY (`id`) )
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_spanish_ci;


-- -----------------------------------------------------
-- Table `datoswebeval`.`evaluacion_pregunta`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `datoswebeval`.`evaluacion_pregunta` ;

CREATE  TABLE IF NOT EXISTS `datoswebeval`.`evaluacion_pregunta` (
  `id` INT NOT NULL AUTO_INCREMENT ,
  `evaluacion_id` INT NOT NULL ,
  `tema_id` INT NULL ,
  `pregunta_id` INT NULL ,
  `dificultad` FLOAT NULL ,
  `pregunta_valor` FLOAT NULL ,
  `penalizacion` FLOAT NULL ,
  PRIMARY KEY (`id`, `evaluacion_id`) ,
  INDEX `fk_pregunta_plantilla_plantilla1` (`evaluacion_id` ASC) ,
  CONSTRAINT `fk_pregunta_plantilla_plantilla1`
    FOREIGN KEY (`evaluacion_id` )
    REFERENCES `datoswebeval`.`evaluacion` (`id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_spanish_ci;


-- -----------------------------------------------------
-- Table `datoswebeval`.`grado_confianza`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `datoswebeval`.`grado_confianza` ;

CREATE  TABLE IF NOT EXISTS `datoswebeval`.`grado_confianza` (
  `id` INT NOT NULL AUTO_INCREMENT ,
  `evaluacion_id` INT NOT NULL ,
  `nombre` VARCHAR(512) NULL ,
  `orden` INT NULL ,
  `acierto` FLOAT NULL ,
  `fallo` FLOAT NULL ,
  PRIMARY KEY (`id`, `evaluacion_id`) ,
  INDEX `fk_grado_confianza_evaluacion1` (`evaluacion_id` ASC) ,
  CONSTRAINT `fk_grado_confianza_evaluacion1`
    FOREIGN KEY (`evaluacion_id` )
    REFERENCES `datoswebeval`.`evaluacion` (`id` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_spanish_ci;



SET SQL_MODE=@OLD_SQL_MODE;
SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS;
SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS;

-- -----------------------------------------------------
-- Data for table `datoswebeval`.`centro`
-- -----------------------------------------------------
START TRANSACTION;

INSERT INTO `datoswebeval`.`centro` (`id`, `nombre`, `siglas`, `descripcion`) VALUES (NULL, 'Escuela Técnica Superior de Ingeniería Informática', 'ETSII', 'ETSII ');
INSERT INTO `datoswebeval`.`centro` (`id`, `nombre`, `siglas`, `descripcion`) VALUES (NULL, 'Escuela Técnica Superior de Ingeniería de Diseño', 'ETSID', 'ETSID');
INSERT INTO `datoswebeval`.`centro` (`id`, `nombre`, `siglas`, `descripcion`) VALUES (NULL, 'Escuela Técnica Superior de Ingeniería de Telecomunicación', 'ETSIT', 'ETSIT');

COMMIT;

-- -----------------------------------------------------
-- Data for table `datoswebeval`.`curso`
-- -----------------------------------------------------
START TRANSACTION;

INSERT INTO `datoswebeval`.`curso` (`id`, `nombre`, `descripcion`) VALUES (1, '2009-2010', '-');
INSERT INTO `datoswebeval`.`curso` (`id`, `nombre`, `descripcion`) VALUES (2, '2010-2011', '-');
INSERT INTO `datoswebeval`.`curso` (`id`, `nombre`, `descripcion`) VALUES (3, '2011-2012', '-');

COMMIT;

-- -----------------------------------------------------
-- Data for table `datoswebeval`.`asignatura`
-- -----------------------------------------------------
START TRANSACTION;

INSERT INTO `datoswebeval`.`asignatura` (`id`, `codigo`, `siglas`, `nombre`, `descripcion`, `creditos_teoria`, `creditos_laboratorio`, `centro_id`, `curso_id`) VALUES (1, '5862', 'RAL', 'Configuración Administración e interconexión de redes de área Local', 'CAIRAL', 3, 3, 1, 1);
INSERT INTO `datoswebeval`.`asignatura` (`id`, `codigo`, `siglas`, `nombre`, `descripcion`, `creditos_teoria`, `creditos_laboratorio`, `centro_id`, `curso_id`) VALUES (2, '1000', 'FCO', 'Grado en Ingeniería Informática- Fundamento de los computadores', 'GII-FCO', 3, 3, 1, 1);
INSERT INTO `datoswebeval`.`asignatura` (`id`, `codigo`, `siglas`, `nombre`, `descripcion`, `creditos_teoria`, `creditos_laboratorio`, `centro_id`, `curso_id`) VALUES (3, '1100', 'AM', 'Análisis Matemático', 'AM', 3, 3, 1, 1);
INSERT INTO `datoswebeval`.`asignatura` (`id`, `codigo`, `siglas`, `nombre`, `descripcion`, `creditos_teoria`, `creditos_laboratorio`, `centro_id`, `curso_id`) VALUES (4, '1088', 'DSISIN', 'Diseño de Sistemas Informáticos Industriales', 'Curso: 3º Ingeniero Técnico Industrial, especialidad Electrónica', 6, 6, 2, 3);

COMMIT;

-- -----------------------------------------------------
-- Data for table `datoswebeval`.`autor`
-- -----------------------------------------------------
START TRANSACTION;

INSERT INTO `datoswebeval`.`autor` (`id`, `dni`, `primerNombre`, `segundoNombre`, `apellidoPaterno`, `apellidoMaterno`, `direccion`, `telefono`, `movilA`, `usuario`, `clave`, `email`, `despacho`) VALUES (1, '26747654', 'Lenin', 'Guillermo', 'Lemus', 'Zúñiga', 'UPVDISCA', '963879708', '629636209', 'lemus', '26747654', 'lemus@upvnet.upv.es', 'DISCA ETSII iG-2S2');
INSERT INTO `datoswebeval`.`autor` (`id`, `dni`, `primerNombre`, `segundoNombre`, `apellidoPaterno`, `apellidoMaterno`, `direccion`, `telefono`, `movilA`, `usuario`, `clave`, `email`, `despacho`) VALUES (NULL, NULL, 'Ángel', 'Francisco', 'Perles', 'Ivars', 'Universitat Politècnica de València\nCamí de Vera, s/n\n46022 València\nEspanya', '963877000 ext. 75775', NULL, NULL, NULL, 'aperles@disca.upv.es', 'DISCA 2S-13');

COMMIT;

-- -----------------------------------------------------
-- Data for table `datoswebeval`.`tipo`
-- -----------------------------------------------------
START TRANSACTION;

INSERT INTO `datoswebeval`.`tipo` (`id`, `nombre`, `descripcion`) VALUES (1, 'Verdadero/Falso', 'Verdadero o falso');
INSERT INTO `datoswebeval`.`tipo` (`id`, `nombre`, `descripcion`) VALUES (2, 'Opcion Multiple', 'Opcion multiple');
INSERT INTO `datoswebeval`.`tipo` (`id`, `nombre`, `descripcion`) VALUES (3, 'Respuesta Libre', 'Respuesta libre');

COMMIT;

-- -----------------------------------------------------
-- Data for table `datoswebeval`.`pregunta`
-- -----------------------------------------------------
START TRANSACTION;

INSERT INTO `datoswebeval`.`pregunta` (`id`, `fecha_creacion`, `fecha_modificacion`, `titulo`, `codigo`, `enunciado`, `palabras_clave`, `dificultad`, `tipo_id`) VALUES (1, '2009-10-07', '2011-07-06', '¿En que puerto escucha el servidor DHCP?', NULL, '¿En que puerto escucha el servidor DHCP?', 'puerto servidor', 4, 2);
INSERT INTO `datoswebeval`.`pregunta` (`id`, `fecha_creacion`, `fecha_modificacion`, `titulo`, `codigo`, `enunciado`, `palabras_clave`, `dificultad`, `tipo_id`) VALUES (2, '2009-10-07', '2011-07-06', '¿El cliente DHCP envía el mensaje DHCPOFFER?', NULL, '¿El cliente DHCP envía el mensaje DHCPOFFER?', 'cliente DHCP', 5, 1);
INSERT INTO `datoswebeval`.`pregunta` (`id`, `fecha_creacion`, `fecha_modificacion`, `titulo`, `codigo`, `enunciado`, `palabras_clave`, `dificultad`, `tipo_id`) VALUES (3, '2009-10-07', '2011-07-06', 'Los ámbitos (DHCP) se utilizan para definir rangos de direcciones IP.', NULL, 'Los ámbitos (DHCP) se utilizan para definir rangos de direcciones IP.', 'Direccion IP', 5, 1);
INSERT INTO `datoswebeval`.`pregunta` (`id`, `fecha_creacion`, `fecha_modificacion`, `titulo`, `codigo`, `enunciado`, `palabras_clave`, `dificultad`, `tipo_id`) VALUES (4, '2009-10-07', '2011-07-06', 'Selecciona el grupo de mensajes que únicamente envia el servidor DHCP.', NULL, 'Selecciona el grupo de mensajes que únicamente envia el servidor DHCP.', 'mensaje servidor DHCP', 7, 2);
INSERT INTO `datoswebeval`.`pregunta` (`id`, `fecha_creacion`, `fecha_modificacion`, `titulo`, `codigo`, `enunciado`, `palabras_clave`, `dificultad`, `tipo_id`) VALUES (5, '2009-10-07', '2011-07-06', '¿En que puerto escucha el servidor DNS?', NULL, '¿En que puerto escucha el servidor DNS?', 'escucha servidor DNS', 3, 2);
INSERT INTO `datoswebeval`.`pregunta` (`id`, `fecha_creacion`, `fecha_modificacion`, `titulo`, `codigo`, `enunciado`, `palabras_clave`, `dificultad`, `tipo_id`) VALUES (6, '2009-10-07', '2011-07-06', '¿La búsqueda directa sirve para que a partir de una dirección IP se obtenga el nombre de un recurso de red?', NULL, '¿La búsqueda directa sirve para que a partir de una dirección IP se obtenga el nombre de un recurso de red?', 'busqueda directa', 6, 1);
INSERT INTO `datoswebeval`.`pregunta` (`id`, `fecha_creacion`, `fecha_modificacion`, `titulo`, `codigo`, `enunciado`, `palabras_clave`, `dificultad`, `tipo_id`) VALUES (7, '2009-10-07', '2011-07-06', '¿La busqueda inversa sirve para que a partir de una direccion IP se obtenga el nombre de un recurso de red?', NULL, '¿La busqueda inversa sirve para que a partir de una direccion IP se obtenga el nombre de un recurso de red?', 'busqueda inversa', 6, 1);
INSERT INTO `datoswebeval`.`pregunta` (`id`, `fecha_creacion`, `fecha_modificacion`, `titulo`, `codigo`, `enunciado`, `palabras_clave`, `dificultad`, `tipo_id`) VALUES (8, '2009-10-07', '2011-07-06', 'El DNS es una base de datos distribuida por toda Internet', NULL, 'El DNS es una base de datos distribuida por toda Internet', 'DNS', 5, 1);
INSERT INTO `datoswebeval`.`pregunta` (`id`, `fecha_creacion`, `fecha_modificacion`, `titulo`, `codigo`, `enunciado`, `palabras_clave`, `dificultad`, `tipo_id`) VALUES (9, '2009-10-07', '2011-07-06', 'El servidor DNS se encarga de asignar direcicones IP.', NULL, 'El servidor DNS se encarga de asignar direcicones IP.', 'DNS', 3, 1);
INSERT INTO `datoswebeval`.`pregunta` (`id`, `fecha_creacion`, `fecha_modificacion`, `titulo`, `codigo`, `enunciado`, `palabras_clave`, `dificultad`, `tipo_id`) VALUES (10, '2010-10-13', '2011-07-06', '¿Cual de las siguientes afirmaciones es falsa?', NULL, '¿Cual de las siguientes afirmaciones es falsa?', 'falsa ICMP', 6, 2);
INSERT INTO `datoswebeval`.`pregunta` (`id`, `fecha_creacion`, `fecha_modificacion`, `titulo`, `codigo`, `enunciado`, `palabras_clave`, `dificultad`, `tipo_id`) VALUES (11, '2010-10-13', '2011-07-06', '¿Cual de los siguientes mensajes NO utiliza ICMP?', NULL, '¿Cual de los siguientes mensajes NO utiliza ICMP?', 'mensaje ICMP', 6, 2);
INSERT INTO `datoswebeval`.`pregunta` (`id`, `fecha_creacion`, `fecha_modificacion`, `titulo`, `codigo`, `enunciado`, `palabras_clave`, `dificultad`, `tipo_id`) VALUES (12, '2010-10-13', '2011-07-06', '¿Cual de las siguientes aplicaciones NO Utiliza ICMP?', NULL, '¿Cual de las siguientes aplicaciones NO Utiliza ICMP?', 'aplicaciones ICMP', 5, 2);
INSERT INTO `datoswebeval`.`pregunta` (`id`, `fecha_creacion`, `fecha_modificacion`, `titulo`, `codigo`, `enunciado`, `palabras_clave`, `dificultad`, `tipo_id`) VALUES (13, '2010-11-03', '2011-07-06', 'Indica que afirmación es FALSA respecto a NAT.', NULL, 'Indica que afirmación es FALSA respecto a NAT.', 'falsa NAT', 6, 2);
INSERT INTO `datoswebeval`.`pregunta` (`id`, `fecha_creacion`, `fecha_modificacion`, `titulo`, `codigo`, `enunciado`, `palabras_clave`, `dificultad`, `tipo_id`) VALUES (14, '2010-11-03', '2011-07-06', 'PATes el acrónimo de Redireccionamiento de direcciones de puerto (Port address redirection), con PAT es posible cambiar tanto la dirección de un puerto como el de una IP.', NULL, 'PATes el acrónimo de Redireccionamiento de direcciones de puerto (Port address redirection), con PAT es posible cambiar tanto la dirección de un puerto como el de una IP.', 'PAT', 8, 1);
INSERT INTO `datoswebeval`.`pregunta` (`id`, `fecha_creacion`, `fecha_modificacion`, `titulo`, `codigo`, `enunciado`, `palabras_clave`, `dificultad`, `tipo_id`) VALUES (15, '2010-11-03', '2011-07-06', 'PAT funciona unicamente con TCP y UDP', NULL, 'PAT funciona unicamente con TCP y UDP', 'PAT UDPTCP', 5, 1);
INSERT INTO `datoswebeval`.`pregunta` (`id`, `fecha_creacion`, `fecha_modificacion`, `titulo`, `codigo`, `enunciado`, `palabras_clave`, `dificultad`, `tipo_id`) VALUES (16, '2011-09-09', '2011-09-09', 'Computer functional unit', NULL, '<p>A computer functional unit a specialized electronic device with realizes a specific task?</p>', NULL, 5, 1);
INSERT INTO `datoswebeval`.`pregunta` (`id`, `fecha_creacion`, `fecha_modificacion`, `titulo`, `codigo`, `enunciado`, `palabras_clave`, `dificultad`, `tipo_id`) VALUES (17, '2011-09-09', '2011-09-09', 'The byte is the minimal unit of information?', NULL, '<p>The byte is the minimal unit of information?</p>', NULL, 5, 1);
INSERT INTO `datoswebeval`.`pregunta` (`id`, `fecha_creacion`, `fecha_modificacion`, `titulo`, `codigo`, `enunciado`, `palabras_clave`, `dificultad`, `tipo_id`) VALUES (18, '2011-09-09', '2011-09-09', 'First-generation machines uses transistors?', NULL, '<p>First-generation machines uses transistors?</p>', NULL, 5, 1);
INSERT INTO `datoswebeval`.`pregunta` (`id`, `fecha_creacion`, `fecha_modificacion`, `titulo`, `codigo`, `enunciado`, `palabras_clave`, `dificultad`, `tipo_id`) VALUES (19, '2011-09-09', '2011-09-09', 'Fourth-generation machines are based on microprocessors?', NULL, '<p>Fourth-generation machines are based on microprocessors?</p>', NULL, 5, 1);
INSERT INTO `datoswebeval`.`pregunta` (`id`, `fecha_creacion`, `fecha_modificacion`, `titulo`, `codigo`, `enunciado`, `palabras_clave`, `dificultad`, `tipo_id`) VALUES (20, '2011-09-09', '2011-09-09', 'Convert 10,625 to binary', NULL, '<p>Convert 10,625 to binary</p>', NULL, 5, 3);
INSERT INTO `datoswebeval`.`pregunta` (`id`, `fecha_creacion`, `fecha_modificacion`, `titulo`, `codigo`, `enunciado`, `palabras_clave`, `dificultad`, `tipo_id`) VALUES (21, '2011-11-1', '2011-11-1', 'Si se desea almacenar un número de valores indeterminado en tiempo de compilación', NULL, '<p>En C, si se desea almacenar un número de valores indeterminado en tiempo de compilación\rse hará:</p>', 'C, almacenar valores', 5, 2);
INSERT INTO `datoswebeval`.`pregunta` (`id`, `fecha_creacion`, `fecha_modificacion`, `titulo`, `codigo`, `enunciado`, `palabras_clave`, `dificultad`, `tipo_id`) VALUES (22, '2011-11-1', '2011-11-1', 'Instrucción C es INCORRECTA', NULL, '<p>Dadas las siguientes declaraciones, qué instrucción C es INCORRECTA. int a; int\rdatos[100]; int *p;</p>', NULL, 5, 2);
INSERT INTO `datoswebeval`.`pregunta` (`id`, `fecha_creacion`, `fecha_modificacion`, `titulo`, `codigo`, `enunciado`, `palabras_clave`, `dificultad`, `tipo_id`) VALUES (23, '2011-11-1', '2011-11-1', 'almacenar un número fijo de valores de tipo double', NULL, '<p>En C, si se desea almacenar un número fijo de valores de tipo double se hará:</p>', NULL, 5, 2);
INSERT INTO `datoswebeval`.`pregunta` (`id`, `fecha_creacion`, `fecha_modificacion`, `titulo`, `codigo`, `enunciado`, `palabras_clave`, `dificultad`, `tipo_id`) VALUES (24, '2011-11-1', '2011-11-1', 'Instrucción C es INCORRECTA', NULL, '<p>Dadas las siguientes declaraciones, qué instrucción C es INCORRECTA int a; int datos[100];\rint *p;</p>', NULL, 5, 2);
INSERT INTO `datoswebeval`.`pregunta` (`id`, `fecha_creacion`, `fecha_modificacion`, `titulo`, `codigo`, `enunciado`, `palabras_clave`, `dificultad`, `tipo_id`) VALUES (25, '2011-11-1', '2011-11-1', 'Instrucción C es INCORRECTA', NULL, '<p>Dadas las siguientes declaraciones, qué instrucción C es INCORRECTA int a; int datos[100];\rint *p;</p>', NULL, 5, 2);

COMMIT;

-- -----------------------------------------------------
-- Data for table `datoswebeval`.`autor_has_pregunta`
-- -----------------------------------------------------
START TRANSACTION;

INSERT INTO `datoswebeval`.`autor_has_pregunta` (`autor_id`, `pregunta_id`) VALUES (1, 1);
INSERT INTO `datoswebeval`.`autor_has_pregunta` (`autor_id`, `pregunta_id`) VALUES (1, 2);
INSERT INTO `datoswebeval`.`autor_has_pregunta` (`autor_id`, `pregunta_id`) VALUES (1, 3);
INSERT INTO `datoswebeval`.`autor_has_pregunta` (`autor_id`, `pregunta_id`) VALUES (1, 4);
INSERT INTO `datoswebeval`.`autor_has_pregunta` (`autor_id`, `pregunta_id`) VALUES (1, 5);
INSERT INTO `datoswebeval`.`autor_has_pregunta` (`autor_id`, `pregunta_id`) VALUES (1, 6);
INSERT INTO `datoswebeval`.`autor_has_pregunta` (`autor_id`, `pregunta_id`) VALUES (1, 7);
INSERT INTO `datoswebeval`.`autor_has_pregunta` (`autor_id`, `pregunta_id`) VALUES (1, 8);
INSERT INTO `datoswebeval`.`autor_has_pregunta` (`autor_id`, `pregunta_id`) VALUES (1, 9);
INSERT INTO `datoswebeval`.`autor_has_pregunta` (`autor_id`, `pregunta_id`) VALUES (2, 10);
INSERT INTO `datoswebeval`.`autor_has_pregunta` (`autor_id`, `pregunta_id`) VALUES (2, 11);
INSERT INTO `datoswebeval`.`autor_has_pregunta` (`autor_id`, `pregunta_id`) VALUES (2, 12);
INSERT INTO `datoswebeval`.`autor_has_pregunta` (`autor_id`, `pregunta_id`) VALUES (2, 13);
INSERT INTO `datoswebeval`.`autor_has_pregunta` (`autor_id`, `pregunta_id`) VALUES (2, 14);
INSERT INTO `datoswebeval`.`autor_has_pregunta` (`autor_id`, `pregunta_id`) VALUES (2, 15);
INSERT INTO `datoswebeval`.`autor_has_pregunta` (`autor_id`, `pregunta_id`) VALUES (1, 16);
INSERT INTO `datoswebeval`.`autor_has_pregunta` (`autor_id`, `pregunta_id`) VALUES (1, 17);
INSERT INTO `datoswebeval`.`autor_has_pregunta` (`autor_id`, `pregunta_id`) VALUES (1, 18);
INSERT INTO `datoswebeval`.`autor_has_pregunta` (`autor_id`, `pregunta_id`) VALUES (1, 19);
INSERT INTO `datoswebeval`.`autor_has_pregunta` (`autor_id`, `pregunta_id`) VALUES (1, 20);

COMMIT;

-- -----------------------------------------------------
-- Data for table `datoswebeval`.`tema`
-- -----------------------------------------------------
START TRANSACTION;

INSERT INTO `datoswebeval`.`tema` (`id`, `nombre`, `numero_tema`, `descripcion`, `asignatura_id`, `asignatura_centro_idcentro`) VALUES (1, 'Introducción', 1, 'Introducción', 1, 1);
INSERT INTO `datoswebeval`.`tema` (`id`, `nombre`, `numero_tema`, `descripcion`, `asignatura_id`, `asignatura_centro_idcentro`) VALUES (2, 'Software de red', 2, 'Software de red', 1, 1);
INSERT INTO `datoswebeval`.`tema` (`id`, `nombre`, `numero_tema`, `descripcion`, `asignatura_id`, `asignatura_centro_idcentro`) VALUES (3, 'Modelos de red', 3, 'Modelos de red', 1, 1);
INSERT INTO `datoswebeval`.`tema` (`id`, `nombre`, `numero_tema`, `descripcion`, `asignatura_id`, `asignatura_centro_idcentro`) VALUES (4, 'ARP', 4, 'ARP', 1, 1);
INSERT INTO `datoswebeval`.`tema` (`id`, `nombre`, `numero_tema`, `descripcion`, `asignatura_id`, `asignatura_centro_idcentro`) VALUES (5, 'DNS', 5, 'DNS', 1, 1);
INSERT INTO `datoswebeval`.`tema` (`id`, `nombre`, `numero_tema`, `descripcion`, `asignatura_id`, `asignatura_centro_idcentro`) VALUES (6, 'DHCP', 6, 'DHCP', 1, 1);
INSERT INTO `datoswebeval`.`tema` (`id`, `nombre`, `numero_tema`, `descripcion`, `asignatura_id`, `asignatura_centro_idcentro`) VALUES (7, 'NAT', 7, 'NAT', 1, 1);
INSERT INTO `datoswebeval`.`tema` (`id`, `nombre`, `numero_tema`, `descripcion`, `asignatura_id`, `asignatura_centro_idcentro`) VALUES (8, 'VPN', 8, 'VPN', 1, 1);
INSERT INTO `datoswebeval`.`tema` (`id`, `nombre`, `numero_tema`, `descripcion`, `asignatura_id`, `asignatura_centro_idcentro`) VALUES (9, 'Introducción a los computadores ', 1, 'Introducción a los computadores ', 2, 1);
INSERT INTO `datoswebeval`.`tema` (`id`, `nombre`, `numero_tema`, `descripcion`, `asignatura_id`, `asignatura_centro_idcentro`) VALUES (10, 'Principios del diseño digital ', 2, 'Principios del diseño digital ', 2, 1);
INSERT INTO `datoswebeval`.`tema` (`id`, `nombre`, `numero_tema`, `descripcion`, `asignatura_id`, `asignatura_centro_idcentro`) VALUES (11, 'Bloques combinacionales básicos ', 3, 'Bloques combinacionales básicos ', 2, 1);
INSERT INTO `datoswebeval`.`tema` (`id`, `nombre`, `numero_tema`, `descripcion`, `asignatura_id`, `asignatura_centro_idcentro`) VALUES (12, 'Circuitos secuenciales ', 4, 'Circuitos secuenciales ', 2, 1);
INSERT INTO `datoswebeval`.`tema` (`id`, `nombre`, `numero_tema`, `descripcion`, `asignatura_id`, `asignatura_centro_idcentro`) VALUES (13, 'Bloques secuenciales básicos ', 5, 'Bloques secuenciales básicos ', 2, 1);
INSERT INTO `datoswebeval`.`tema` (`id`, `nombre`, `numero_tema`, `descripcion`, `asignatura_id`, `asignatura_centro_idcentro`) VALUES (14, 'Representación de la información ', 6, 'Representación de la información ', 2, 1);
INSERT INTO `datoswebeval`.`tema` (`id`, `nombre`, `numero_tema`, `descripcion`, `asignatura_id`, `asignatura_centro_idcentro`) VALUES (15, 'Introducción al lenguaje ensamblador ', 7, 'Introducción al lenguaje ensamblador ', 2, 1);
INSERT INTO `datoswebeval`.`tema` (`id`, `nombre`, `numero_tema`, `descripcion`, `asignatura_id`, `asignatura_centro_idcentro`) VALUES (16, 'Punteros', 2, 'Punteros', 4, 2);

COMMIT;

-- -----------------------------------------------------
-- Data for table `datoswebeval`.`evaluacion`
-- -----------------------------------------------------
START TRANSACTION;

INSERT INTO `datoswebeval`.`evaluacion` (`id`, `asignatura_id`, `autor_id`, `tema_id`, `titulo`, `fecha_apertura`, `fecha_cierre`, `valor`, `grado_confianza`, `publicado`) VALUES (1, 4, 2, 16, 'Punteros', NULL, NULL, 10, 0, 0);

COMMIT;

-- -----------------------------------------------------
-- Data for table `datoswebeval`.`pregunta_o_m`
-- -----------------------------------------------------
START TRANSACTION;

INSERT INTO `datoswebeval`.`pregunta_o_m` (`id`, `pregunta_id`, `respuesta`, `correcta`, `refuerzo`) VALUES (1, 1, 'En el puerto 68', 0, '1');
INSERT INTO `datoswebeval`.`pregunta_o_m` (`id`, `pregunta_id`, `respuesta`, `correcta`, `refuerzo`) VALUES (2, 1, 'En el puerto 99', 0, '1');
INSERT INTO `datoswebeval`.`pregunta_o_m` (`id`, `pregunta_id`, `respuesta`, `correcta`, `refuerzo`) VALUES (3, 1, 'En el puerto 16', 0, '1');
INSERT INTO `datoswebeval`.`pregunta_o_m` (`id`, `pregunta_id`, `respuesta`, `correcta`, `refuerzo`) VALUES (4, 1, 'En el puerto 67', 1, '1');
INSERT INTO `datoswebeval`.`pregunta_o_m` (`id`, `pregunta_id`, `respuesta`, `correcta`, `refuerzo`) VALUES (5, 4, 'DHCPREQUEST DHCPOFFER', 0, '1');
INSERT INTO `datoswebeval`.`pregunta_o_m` (`id`, `pregunta_id`, `respuesta`, `correcta`, `refuerzo`) VALUES (6, 4, 'DHCPDISCOVER DHCPDINFORM', 0, '1');
INSERT INTO `datoswebeval`.`pregunta_o_m` (`id`, `pregunta_id`, `respuesta`, `correcta`, `refuerzo`) VALUES (7, 4, 'DHCPDISCOVER DHCPREQUEST', 0, '1');
INSERT INTO `datoswebeval`.`pregunta_o_m` (`id`, `pregunta_id`, `respuesta`, `correcta`, `refuerzo`) VALUES (8, 4, 'DHCPOFFER DHCPACK', 1, '1');
INSERT INTO `datoswebeval`.`pregunta_o_m` (`id`, `pregunta_id`, `respuesta`, `correcta`, `refuerzo`) VALUES (9, 5, 'En el puerto UDP 63', 0, '1');
INSERT INTO `datoswebeval`.`pregunta_o_m` (`id`, `pregunta_id`, `respuesta`, `correcta`, `refuerzo`) VALUES (10, 5, 'En el puerto TCP 53', 1, '1');
INSERT INTO `datoswebeval`.`pregunta_o_m` (`id`, `pregunta_id`, `respuesta`, `correcta`, `refuerzo`) VALUES (11, 5, 'En el puerto TCP 63', 0, '1');
INSERT INTO `datoswebeval`.`pregunta_o_m` (`id`, `pregunta_id`, `respuesta`, `correcta`, `refuerzo`) VALUES (12, 5, 'En los puertos 21 y 22', 0, '1');
INSERT INTO `datoswebeval`.`pregunta_o_m` (`id`, `pregunta_id`, `respuesta`, `correcta`, `refuerzo`) VALUES (13, 10, 'IP proporciona todas las facilidades para informar acerca de errores de enrutado', 1, '1');
INSERT INTO `datoswebeval`.`pregunta_o_m` (`id`, `pregunta_id`, `respuesta`, `correcta`, `refuerzo`) VALUES (14, 10, 'ICMP no logra que IP sea un protocolo confiable', 0, '1');
INSERT INTO `datoswebeval`.`pregunta_o_m` (`id`, `pregunta_id`, `respuesta`, `correcta`, `refuerzo`) VALUES (15, 10, 'IP NO proporciona ninguna facilidad acerca de errores en la entrega de mensajes.', 0, '1');
INSERT INTO `datoswebeval`.`pregunta_o_m` (`id`, `pregunta_id`, `respuesta`, `correcta`, `refuerzo`) VALUES (16, 10, 'ICMP informa acerca de condiciones de control de beneficio de IP.', 0, '1');
INSERT INTO `datoswebeval`.`pregunta_o_m` (`id`, `pregunta_id`, `respuesta`, `correcta`, `refuerzo`) VALUES (17, 11, 'Solicitud de enrutado', 0, '1');
INSERT INTO `datoswebeval`.`pregunta_o_m` (`id`, `pregunta_id`, `respuesta`, `correcta`, `refuerzo`) VALUES (18, 11, 'Respuesta a petición DNS', 1, '1');
INSERT INTO `datoswebeval`.`pregunta_o_m` (`id`, `pregunta_id`, `respuesta`, `correcta`, `refuerzo`) VALUES (19, 11, 'Destino Inalcanzable', 0, '1');
INSERT INTO `datoswebeval`.`pregunta_o_m` (`id`, `pregunta_id`, `respuesta`, `correcta`, `refuerzo`) VALUES (20, 11, 'Respuesta a Echo', 0, '1');
INSERT INTO `datoswebeval`.`pregunta_o_m` (`id`, `pregunta_id`, `respuesta`, `correcta`, `refuerzo`) VALUES (21, 12, 'ping', 0, '1');
INSERT INTO `datoswebeval`.`pregunta_o_m` (`id`, `pregunta_id`, `respuesta`, `correcta`, `refuerzo`) VALUES (22, 12, 'arp', 1, '1');
INSERT INTO `datoswebeval`.`pregunta_o_m` (`id`, `pregunta_id`, `respuesta`, `correcta`, `refuerzo`) VALUES (23, 12, 'echo', 0, '1');
INSERT INTO `datoswebeval`.`pregunta_o_m` (`id`, `pregunta_id`, `respuesta`, `correcta`, `refuerzo`) VALUES (24, 12, 'traceroute', 0, '1');
INSERT INTO `datoswebeval`.`pregunta_o_m` (`id`, `pregunta_id`, `respuesta`, `correcta`, `refuerzo`) VALUES (25, 13, 'NAT se utiliza para cambiar la dirección de un puerto por otro.', 1, '1');
INSERT INTO `datoswebeval`.`pregunta_o_m` (`id`, `pregunta_id`, `respuesta`, `correcta`, `refuerzo`) VALUES (26, 13, 'NAT es el acrónimo de \\\"Network Address Translation\\\" (Traducción de direcciones de red).', 0, '1');
INSERT INTO `datoswebeval`.`pregunta_o_m` (`id`, `pregunta_id`, `respuesta`, `correcta`, `refuerzo`) VALUES (27, 13, 'NATtraduce direcciones IP de acuerdo a una tabla de equivalencias', 0, '1');
INSERT INTO `datoswebeval`.`pregunta_o_m` (`id`, `pregunta_id`, `respuesta`, `correcta`, `refuerzo`) VALUES (28, 13, 'NAT se suele utilizar para conectar a Internet redes IP que utilizan rangos privados (RFC 1918): 10.*.*.*, 172.16-31.*.* y 192.168.0-255.*.', 0, '1');
INSERT INTO `datoswebeval`.`pregunta_o_m` (`id`, `pregunta_id`, `respuesta`, `correcta`, `refuerzo`) VALUES (29, 21, 'Se definirá una estructura a la que se accederá con el operador ->', 1, 'Muy bien');
INSERT INTO `datoswebeval`.`pregunta_o_m` (`id`, `pregunta_id`, `respuesta`, `correcta`, `refuerzo`) VALUES (30, 21, 'Una declaración de un vector tan grande como el mayor número posible de valores', 0, 'Muy mal');
INSERT INTO `datoswebeval`.`pregunta_o_m` (`id`, `pregunta_id`, `respuesta`, `correcta`, `refuerzo`) VALUES (31, 21, 'Uso de la función malloc() cuando se conozca el número de valores a almacenar', 0, 'Muy mal');
INSERT INTO `datoswebeval`.`pregunta_o_m` (`id`, `pregunta_id`, `respuesta`, `correcta`, `refuerzo`) VALUES (32, 21, 'Ninguna de las anteriores', 0, 'Muy mal');
INSERT INTO `datoswebeval`.`pregunta_o_m` (`id`, `pregunta_id`, `respuesta`, `correcta`, `refuerzo`) VALUES (33, 22, '*p=3;', 1, 'Muy bien');
INSERT INTO `datoswebeval`.`pregunta_o_m` (`id`, `pregunta_id`, `respuesta`, `correcta`, `refuerzo`) VALUES (34, 22, 'p=datos;', 0, 'Muy mal');
INSERT INTO `datoswebeval`.`pregunta_o_m` (`id`, `pregunta_id`, `respuesta`, `correcta`, `refuerzo`) VALUES (35, 22, 'p=3;', 0, 'Muy mal');
INSERT INTO `datoswebeval`.`pregunta_o_m` (`id`, `pregunta_id`, `respuesta`, `correcta`, `refuerzo`) VALUES (36, 22, 'Ninguna de las anteriores', 0, 'Muy mal');
INSERT INTO `datoswebeval`.`pregunta_o_m` (`id`, `pregunta_id`, `respuesta`, `correcta`, `refuerzo`) VALUES (37, 23, 'Una declaración de un vector tan grande como el número de valores', 1, 'Muy bien');
INSERT INTO `datoswebeval`.`pregunta_o_m` (`id`, `pregunta_id`, `respuesta`, `correcta`, `refuerzo`) VALUES (38, 23, 'Se definirá una estructura a la que se accederá con el operador ->', 0, 'Muy mal');
INSERT INTO `datoswebeval`.`pregunta_o_m` (`id`, `pregunta_id`, `respuesta`, `correcta`, `refuerzo`) VALUES (39, 23, 'Se declarará un puntero donde almacenar los datos', 0, 'Muy mal');
INSERT INTO `datoswebeval`.`pregunta_o_m` (`id`, `pregunta_id`, `respuesta`, `correcta`, `refuerzo`) VALUES (40, 23, 'Ninguna de las anteriores', 0, 'Muy mal');
INSERT INTO `datoswebeval`.`pregunta_o_m` (`id`, `pregunta_id`, `respuesta`, `correcta`, `refuerzo`) VALUES (41, 24, '*a=p;', 1, 'Muy bien');
INSERT INTO `datoswebeval`.`pregunta_o_m` (`id`, `pregunta_id`, `respuesta`, `correcta`, `refuerzo`) VALUES (42, 24, 'p=&a;', 0, 'Muy mal');
INSERT INTO `datoswebeval`.`pregunta_o_m` (`id`, `pregunta_id`, `respuesta`, `correcta`, `refuerzo`) VALUES (43, 24, '*p=3;', 0, 'Muy mal');
INSERT INTO `datoswebeval`.`pregunta_o_m` (`id`, `pregunta_id`, `respuesta`, `correcta`, `refuerzo`) VALUES (44, 24, 'Ninguna de las anteriores', 0, 'Muy mal');
INSERT INTO `datoswebeval`.`pregunta_o_m` (`id`, `pregunta_id`, `respuesta`, `correcta`, `refuerzo`) VALUES (45, 25, 'p=p+1;', 1, 'Muy bien');
INSERT INTO `datoswebeval`.`pregunta_o_m` (`id`, `pregunta_id`, `respuesta`, `correcta`, `refuerzo`) VALUES (46, 25, '*p=datos[3];', 0, 'Muy mal');
INSERT INTO `datoswebeval`.`pregunta_o_m` (`id`, `pregunta_id`, `respuesta`, `correcta`, `refuerzo`) VALUES (47, 25, 'datos[100]=a;', 0, 'Muy mal');
INSERT INTO `datoswebeval`.`pregunta_o_m` (`id`, `pregunta_id`, `respuesta`, `correcta`, `refuerzo`) VALUES (48, 25, 'Ninguna de las anteriores', 0, 'Muy mal');

COMMIT;

-- -----------------------------------------------------
-- Data for table `datoswebeval`.`pregunta_tema`
-- -----------------------------------------------------
START TRANSACTION;

INSERT INTO `datoswebeval`.`pregunta_tema` (`pregunta_id`, `tema_id`, `tema_asignatura_id`, `tema_asignatura_centro_idcentro`) VALUES (1, 6, 1, 1);
INSERT INTO `datoswebeval`.`pregunta_tema` (`pregunta_id`, `tema_id`, `tema_asignatura_id`, `tema_asignatura_centro_idcentro`) VALUES (2, 6, 1, 1);
INSERT INTO `datoswebeval`.`pregunta_tema` (`pregunta_id`, `tema_id`, `tema_asignatura_id`, `tema_asignatura_centro_idcentro`) VALUES (3, 6, 1, 1);
INSERT INTO `datoswebeval`.`pregunta_tema` (`pregunta_id`, `tema_id`, `tema_asignatura_id`, `tema_asignatura_centro_idcentro`) VALUES (4, 6, 1, 1);
INSERT INTO `datoswebeval`.`pregunta_tema` (`pregunta_id`, `tema_id`, `tema_asignatura_id`, `tema_asignatura_centro_idcentro`) VALUES (5, 5, 1, 1);
INSERT INTO `datoswebeval`.`pregunta_tema` (`pregunta_id`, `tema_id`, `tema_asignatura_id`, `tema_asignatura_centro_idcentro`) VALUES (6, 5, 1, 1);
INSERT INTO `datoswebeval`.`pregunta_tema` (`pregunta_id`, `tema_id`, `tema_asignatura_id`, `tema_asignatura_centro_idcentro`) VALUES (7, 5, 1, 1);
INSERT INTO `datoswebeval`.`pregunta_tema` (`pregunta_id`, `tema_id`, `tema_asignatura_id`, `tema_asignatura_centro_idcentro`) VALUES (8, 5, 1, 1);
INSERT INTO `datoswebeval`.`pregunta_tema` (`pregunta_id`, `tema_id`, `tema_asignatura_id`, `tema_asignatura_centro_idcentro`) VALUES (9, 5, 1, 1);
INSERT INTO `datoswebeval`.`pregunta_tema` (`pregunta_id`, `tema_id`, `tema_asignatura_id`, `tema_asignatura_centro_idcentro`) VALUES (10, 4, 1, 1);
INSERT INTO `datoswebeval`.`pregunta_tema` (`pregunta_id`, `tema_id`, `tema_asignatura_id`, `tema_asignatura_centro_idcentro`) VALUES (11, 4, 1, 1);
INSERT INTO `datoswebeval`.`pregunta_tema` (`pregunta_id`, `tema_id`, `tema_asignatura_id`, `tema_asignatura_centro_idcentro`) VALUES (12, 3, 1, 1);
INSERT INTO `datoswebeval`.`pregunta_tema` (`pregunta_id`, `tema_id`, `tema_asignatura_id`, `tema_asignatura_centro_idcentro`) VALUES (13, 7, 1, 1);
INSERT INTO `datoswebeval`.`pregunta_tema` (`pregunta_id`, `tema_id`, `tema_asignatura_id`, `tema_asignatura_centro_idcentro`) VALUES (14, 7, 1, 1);
INSERT INTO `datoswebeval`.`pregunta_tema` (`pregunta_id`, `tema_id`, `tema_asignatura_id`, `tema_asignatura_centro_idcentro`) VALUES (15, 7, 1, 1);
INSERT INTO `datoswebeval`.`pregunta_tema` (`pregunta_id`, `tema_id`, `tema_asignatura_id`, `tema_asignatura_centro_idcentro`) VALUES (16, 9, 2, 1);
INSERT INTO `datoswebeval`.`pregunta_tema` (`pregunta_id`, `tema_id`, `tema_asignatura_id`, `tema_asignatura_centro_idcentro`) VALUES (17, 9, 2, 1);
INSERT INTO `datoswebeval`.`pregunta_tema` (`pregunta_id`, `tema_id`, `tema_asignatura_id`, `tema_asignatura_centro_idcentro`) VALUES (18, 9, 2, 1);
INSERT INTO `datoswebeval`.`pregunta_tema` (`pregunta_id`, `tema_id`, `tema_asignatura_id`, `tema_asignatura_centro_idcentro`) VALUES (19, 9, 2, 1);
INSERT INTO `datoswebeval`.`pregunta_tema` (`pregunta_id`, `tema_id`, `tema_asignatura_id`, `tema_asignatura_centro_idcentro`) VALUES (20, 9, 2, 1);
INSERT INTO `datoswebeval`.`pregunta_tema` (`pregunta_id`, `tema_id`, `tema_asignatura_id`, `tema_asignatura_centro_idcentro`) VALUES (21, 16, 4, 2);
INSERT INTO `datoswebeval`.`pregunta_tema` (`pregunta_id`, `tema_id`, `tema_asignatura_id`, `tema_asignatura_centro_idcentro`) VALUES (22, 16, 4, 2);
INSERT INTO `datoswebeval`.`pregunta_tema` (`pregunta_id`, `tema_id`, `tema_asignatura_id`, `tema_asignatura_centro_idcentro`) VALUES (23, 16, 4, 2);
INSERT INTO `datoswebeval`.`pregunta_tema` (`pregunta_id`, `tema_id`, `tema_asignatura_id`, `tema_asignatura_centro_idcentro`) VALUES (24, 16, 4, 2);
INSERT INTO `datoswebeval`.`pregunta_tema` (`pregunta_id`, `tema_id`, `tema_asignatura_id`, `tema_asignatura_centro_idcentro`) VALUES (25, 16, 4, 2);

COMMIT;

-- -----------------------------------------------------
-- Data for table `datoswebeval`.`pregunta_v_f`
-- -----------------------------------------------------
START TRANSACTION;

INSERT INTO `datoswebeval`.`pregunta_v_f` (`pregunta_id`, `correcta`, `refuerzo_positivo`, `refuerzo_negativo`) VALUES (2, 0, '1', '1');
INSERT INTO `datoswebeval`.`pregunta_v_f` (`pregunta_id`, `correcta`, `refuerzo_positivo`, `refuerzo_negativo`) VALUES (3, 0, '1', '1');
INSERT INTO `datoswebeval`.`pregunta_v_f` (`pregunta_id`, `correcta`, `refuerzo_positivo`, `refuerzo_negativo`) VALUES (6, 0, '1', '1');
INSERT INTO `datoswebeval`.`pregunta_v_f` (`pregunta_id`, `correcta`, `refuerzo_positivo`, `refuerzo_negativo`) VALUES (7, 1, '1', '1');
INSERT INTO `datoswebeval`.`pregunta_v_f` (`pregunta_id`, `correcta`, `refuerzo_positivo`, `refuerzo_negativo`) VALUES (8, 0, '1', '1');
INSERT INTO `datoswebeval`.`pregunta_v_f` (`pregunta_id`, `correcta`, `refuerzo_positivo`, `refuerzo_negativo`) VALUES (9, 0, '1', '1');
INSERT INTO `datoswebeval`.`pregunta_v_f` (`pregunta_id`, `correcta`, `refuerzo_positivo`, `refuerzo_negativo`) VALUES (14, 0, '1', '1');
INSERT INTO `datoswebeval`.`pregunta_v_f` (`pregunta_id`, `correcta`, `refuerzo_positivo`, `refuerzo_negativo`) VALUES (15, 1, '1', '1');
INSERT INTO `datoswebeval`.`pregunta_v_f` (`pregunta_id`, `correcta`, `refuerzo_positivo`, `refuerzo_negativo`) VALUES (16, 1, NULL, NULL);
INSERT INTO `datoswebeval`.`pregunta_v_f` (`pregunta_id`, `correcta`, `refuerzo_positivo`, `refuerzo_negativo`) VALUES (17, 0, NULL, NULL);
INSERT INTO `datoswebeval`.`pregunta_v_f` (`pregunta_id`, `correcta`, `refuerzo_positivo`, `refuerzo_negativo`) VALUES (18, 0, NULL, NULL);
INSERT INTO `datoswebeval`.`pregunta_v_f` (`pregunta_id`, `correcta`, `refuerzo_positivo`, `refuerzo_negativo`) VALUES (19, 1, NULL, NULL);

COMMIT;

-- -----------------------------------------------------
-- Data for table `datoswebeval`.`menu_gestion`
-- -----------------------------------------------------
START TRANSACTION;

INSERT INTO `datoswebeval`.`menu_gestion` (`id`, `nombre`, `orden`, `vista`, `imagen`) VALUES (NULL, 'Gestion de Centros', 1, 'Centros', 'Centros.png');
INSERT INTO `datoswebeval`.`menu_gestion` (`id`, `nombre`, `orden`, `vista`, `imagen`) VALUES (NULL, 'Gestion de Asignaturas', 2, 'Asignaturas', 'Asignaturas.png');
INSERT INTO `datoswebeval`.`menu_gestion` (`id`, `nombre`, `orden`, `vista`, `imagen`) VALUES (NULL, 'Gestion de Autores', 3, 'Autores', 'Autores.png');
INSERT INTO `datoswebeval`.`menu_gestion` (`id`, `nombre`, `orden`, `vista`, `imagen`) VALUES (NULL, 'Gestion de Temas', 4, 'Temas', 'Temas.png');
INSERT INTO `datoswebeval`.`menu_gestion` (`id`, `nombre`, `orden`, `vista`, `imagen`) VALUES (NULL, 'Gestion de Tipos', 5, 'Tipos', 'Tipos.png');
INSERT INTO `datoswebeval`.`menu_gestion` (`id`, `nombre`, `orden`, `vista`, `imagen`) VALUES (NULL, 'Gestion de Preguntas', 6, 'Preguntas', 'Preguntas.png');
INSERT INTO `datoswebeval`.`menu_gestion` (`id`, `nombre`, `orden`, `vista`, `imagen`) VALUES (NULL, 'Gestion de Cursos', 7, 'Cursos', 'Cursos.png');
INSERT INTO `datoswebeval`.`menu_gestion` (`id`, `nombre`, `orden`, `vista`, `imagen`) VALUES (NULL, 'Gestion de Alumnos', 8, 'Alumnos', 'Alumnos.png');
INSERT INTO `datoswebeval`.`menu_gestion` (`id`, `nombre`, `orden`, `vista`, `imagen`) VALUES (NULL, 'Gestion de Respuestas', 9, 'evaluaciones_alumnos', 'Corregir.png');
INSERT INTO `datoswebeval`.`menu_gestion` (`id`, `nombre`, `orden`, `vista`, `imagen`) VALUES (NULL, 'Gestion de Evaluaciones', 10, 'Evaluaciones', 'Evaluaciones.png');

COMMIT;

-- -----------------------------------------------------
-- Data for table `datoswebeval`.`evaluacion_pregunta`
-- -----------------------------------------------------
START TRANSACTION;

INSERT INTO `datoswebeval`.`evaluacion_pregunta` (`id`, `evaluacion_id`, `tema_id`, `pregunta_id`, `dificultad`, `pregunta_valor`, `penalizacion`) VALUES (1, 1, 16, 21, 5, 2, 1);
INSERT INTO `datoswebeval`.`evaluacion_pregunta` (`id`, `evaluacion_id`, `tema_id`, `pregunta_id`, `dificultad`, `pregunta_valor`, `penalizacion`) VALUES (2, 1, 16, 22, 5, 2, 1);
INSERT INTO `datoswebeval`.`evaluacion_pregunta` (`id`, `evaluacion_id`, `tema_id`, `pregunta_id`, `dificultad`, `pregunta_valor`, `penalizacion`) VALUES (3, 1, 16, 23, 5, 2, 1);
INSERT INTO `datoswebeval`.`evaluacion_pregunta` (`id`, `evaluacion_id`, `tema_id`, `pregunta_id`, `dificultad`, `pregunta_valor`, `penalizacion`) VALUES (4, 1, 16, 24, 5, 2, 1);
INSERT INTO `datoswebeval`.`evaluacion_pregunta` (`id`, `evaluacion_id`, `tema_id`, `pregunta_id`, `dificultad`, `pregunta_valor`, `penalizacion`) VALUES (5, 1, 16, 25, 5, 2, 1);

COMMIT;
